#========================================================================================
# package      DE_EPAGES::ServiRed::t::unit::PaymentSHA256
# state        public
#----------------------------------------------------------------------------------------
# description  Test class use to test the DE_EPAGES::ServiRed::t::unit::PaymentSHA256
#========================================================================================
package DE_EPAGES::ServiRed::t::unit::PaymentSHA256;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::EpagesObject;
use Test::MockObject::Extends;
use Test::More;

use DE_EPAGES::Test::Mock::MockifyServlet;
use DE_EPAGES::ServiRed::API::PaymentSHA256;

use strict;

sub test {
    my $self = shift;

    $self->test_JsonChainGeneration();

    done_testing();
}

#----------------------------------------------------------------------------------------
sub test_JsonChainGeneration {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $mockedPayment = $self->_createMockedPaymentSHA256($self->_createMockedCustomerOrder());

    my $gotSecretKey = $mockedPayment->getSecretKey();
    my $expectedSecretKey = 'sq7HjrUOBfKmC576ILgskD5srU870gJ7';

    is ( $gotSecretKey, $expectedSecretKey, "$SubTestName - mocked secret key can be obtained");
    $mockedPayment->{'SecretKey'} = $expectedSecretKey;
}

#----------------------------------------------------------------------------------------
sub _createPaymentMethodServired {
    my $self = shift;

    my $hAttributes = {
        'MerchantCode' => '297285611',
        'MerchantTerminal' => '2',
        'SecretKey' => 'sq7HjrUOBfKmC576ILgskD5srU870gJ7'

    };
    return DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::ServiRed::API::Object::PaymentMethodServiRed', $hAttributes );
}

#----------------------------------------------------------------------------------------
sub _createLineItemPaymentServiRed {
    my $self = shift;

    my $hAttributes = {
        'PaymentMethod' => $self->_createPaymentMethodServired(),
    };
    return DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::ServiRed::API::Object::LineItemPaymentServiRed', $hAttributes );
}

#----------------------------------------------------------------------------------------
sub _createLineItemContainer {
    my $self = shift;

    my $hAttributes = {
        'Payment' => $self->_createLineItemPaymentServiRed()
    };
    return DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::LineItemContainer', $hAttributes );
}

#----------------------------------------------------------------------------------------
sub _createMockedCustomerOrder {
    my $self = shift;

    my $hAttributes = {
        'LineItemContainer' => $self->_createLineItemContainer()
    };

    return DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::CustomerOrder', $hAttributes );
}

#----------------------------------------------------------------------------------------
sub _createMockedServlet {
    my $self = shift;
    my ($Object) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyServlet->new($Object);

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createMockedPaymentSHA256 {
    my $self = shift;
    my ($Object) = @_;

    my $mockedServlet = $self->_createMockedServlet($Object);
    my $PaymentSHA256 = DE_EPAGES::ServiRed::API::PaymentSHA256->new($mockedServlet);

    my $mockedPaymentSHA256 = Test::MockObject::Extends->new( $PaymentSHA256 );

    return $mockedPaymentSHA256;
}

__PACKAGE__->runScript();

1;
